<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="sk_SK" sourcelanguage="en_US">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="config.py" line="66"/>
        <source>Behavior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="66"/>
        <source>Automatically save documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="66"/>
        <source>Restore window geometry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="66"/>
        <source>Restore live preview state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="66"/>
        <source>Open external links in ReText window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="66"/>
        <source>Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="66"/>
        <source>Highlight current line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="66"/>
        <source>Show line numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="66"/>
        <source>Tab key inserts spaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="66"/>
        <source>Tabulation width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="66"/>
        <source>Display right margin at column</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="66"/>
        <source>Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="66"/>
        <source>Icon theme name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="66"/>
        <source>Color scheme file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="66"/>
        <source>Stylesheet file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="66"/>
        <source>Markdown syntax extensions (comma-separated)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="102"/>
        <source>Help</source>
        <translation type="unfinished">Pomocník</translation>
    </message>
</context>
<context>
    <name>FileSelectButton</name>
    <message>
        <location filename="config.py" line="33"/>
        <source>(none)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="40"/>
        <source>Select file to open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="dialogs.py" line="44"/>
        <source>Enter locale name (example: en_US)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dialogs.py" line="49"/>
        <source>Set as default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Proxy</name>
    <message>
        <location filename="fakevimeditor.py" line="64"/>
        <source>No write since last change (add ! to override)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fakevimeditor.py" line="121"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="window.py" line="82"/>
        <source>File toolbar</source>
        <translation>Panel nástrojov pre súbor</translation>
    </message>
    <message>
        <location filename="window.py" line="84"/>
        <source>Edit toolbar</source>
        <translation>Panel nástrojov pre úpravy</translation>
    </message>
    <message>
        <location filename="window.py" line="86"/>
        <source>Search toolbar</source>
        <translation>Panel nástrojov pre vyhľadávanie</translation>
    </message>
    <message>
        <location filename="window.py" line="90"/>
        <source>New</source>
        <translation>Nový</translation>
    </message>
    <message>
        <location filename="window.py" line="93"/>
        <source>Open</source>
        <translation>Otvoriť</translation>
    </message>
    <message>
        <location filename="window.py" line="101"/>
        <source>Save</source>
        <translation>Uložiť</translation>
    </message>
    <message>
        <location filename="window.py" line="105"/>
        <source>Save as</source>
        <translation>Uložiť ako</translation>
    </message>
    <message>
        <location filename="window.py" line="111"/>
        <source>Print</source>
        <translation>Tlačiť</translation>
    </message>
    <message>
        <location filename="window.py" line="114"/>
        <source>Print preview</source>
        <translation>Ukážka pred tlačou</translation>
    </message>
    <message>
        <location filename="window.py" line="116"/>
        <source>View HTML code</source>
        <translation>Zobraziť HTML kód</translation>
    </message>
    <message>
        <location filename="window.py" line="121"/>
        <source>Find text</source>
        <translation>Nájsť text</translation>
    </message>
    <message>
        <location filename="window.py" line="125"/>
        <source>Preview</source>
        <translation>Náhľad</translation>
    </message>
    <message>
        <location filename="window.py" line="135"/>
        <source>Live preview</source>
        <translation>Priebežný náhľad</translation>
    </message>
    <message>
        <location filename="window.py" line="145"/>
        <source>Fullscreen mode</source>
        <translation>Celoobrazovkový režim</translation>
    </message>
    <message>
        <location filename="window.py" line="155"/>
        <source>Quit</source>
        <translation>Quit</translation>
    </message>
    <message>
        <location filename="window.py" line="158"/>
        <source>Undo</source>
        <translation>Späť</translation>
    </message>
    <message>
        <location filename="window.py" line="160"/>
        <source>Redo</source>
        <translation>Znova</translation>
    </message>
    <message>
        <location filename="window.py" line="162"/>
        <source>Copy</source>
        <translation>Kopírovať</translation>
    </message>
    <message>
        <location filename="window.py" line="164"/>
        <source>Cut</source>
        <translation>Vystrihnúť</translation>
    </message>
    <message>
        <location filename="window.py" line="166"/>
        <source>Paste</source>
        <translation>Vložiť</translation>
    </message>
    <message>
        <location filename="window.py" line="176"/>
        <source>Enable</source>
        <translation>Povoliť</translation>
    </message>
    <message>
        <location filename="window.py" line="177"/>
        <source>Set locale</source>
        <translation>Nastaviť lokalizáciu</translation>
    </message>
    <message>
        <location filename="window.py" line="178"/>
        <source>Use WebKit renderer</source>
        <translation>Použiť k vykresľovaniu WebKit</translation>
    </message>
    <message>
        <location filename="window.py" line="181"/>
        <source>Next</source>
        <translation>Nasledujúci</translation>
    </message>
    <message>
        <location filename="window.py" line="183"/>
        <source>Previous</source>
        <translation>Predchádzajúci</translation>
    </message>
    <message>
        <location filename="window.py" line="185"/>
        <source>Get help online</source>
        <translation>Získať online pomoc</translation>
    </message>
    <message>
        <location filename="window.py" line="189"/>
        <source>About Qt</source>
        <translation>O Qt</translation>
    </message>
    <message>
        <location filename="window.py" line="209"/>
        <source>Bold</source>
        <translation>Tučné</translation>
    </message>
    <message>
        <location filename="window.py" line="211"/>
        <source>Italic</source>
        <translation>Kurzíva</translation>
    </message>
    <message>
        <location filename="window.py" line="213"/>
        <source>Underline</source>
        <translation>Podčiarknuté</translation>
    </message>
    <message>
        <location filename="window.py" line="221"/>
        <source>Tags</source>
        <translation>Značky</translation>
    </message>
    <message>
        <location filename="window.py" line="225"/>
        <source>Symbols</source>
        <translation>Symboly</translation>
    </message>
    <message>
        <location filename="window.py" line="232"/>
        <source>File</source>
        <translation>Súbor</translation>
    </message>
    <message>
        <location filename="window.py" line="233"/>
        <source>Edit</source>
        <translation>Upraviť</translation>
    </message>
    <message>
        <location filename="window.py" line="234"/>
        <source>Help</source>
        <translation>Pomocník</translation>
    </message>
    <message>
        <location filename="window.py" line="237"/>
        <source>Open recent</source>
        <translation>Otvoriť nedávne</translation>
    </message>
    <message>
        <location filename="window.py" line="250"/>
        <source>Export</source>
        <translation>Export</translation>
    </message>
    <message>
        <location filename="window.py" line="271"/>
        <source>Spell check</source>
        <translation>Kontrola pravopisu</translation>
    </message>
    <message>
        <location filename="window.py" line="282"/>
        <source>Formatting</source>
        <translation>Formátovanie</translation>
    </message>
    <message>
        <location filename="window.py" line="323"/>
        <source>Search</source>
        <translation>Vyhľadávanie</translation>
    </message>
    <message>
        <location filename="window.py" line="325"/>
        <source>Case sensitively</source>
        <translation>Rozlišovanie veľkosti písmen</translation>
    </message>
    <message>
        <location filename="window.py" line="1141"/>
        <source>New document</source>
        <translation>Nový dokument</translation>
    </message>
    <message>
        <location filename="window.py" line="748"/>
        <source>Please, save the file somewhere.</source>
        <translation>Uložte prosím niekam súbor.</translation>
    </message>
    <message>
        <location filename="window.py" line="180"/>
        <source>Show directory</source>
        <translation>Zobraziť priečinok</translation>
    </message>
    <message>
        <location filename="window.py" line="868"/>
        <source>Select one or several files to open</source>
        <translation>Vyberte jeden alebo viac súborov k otvoreniu</translation>
    </message>
    <message>
        <location filename="window.py" line="868"/>
        <source>Supported files</source>
        <translation>Podporované súbory</translation>
    </message>
    <message>
        <location filename="window.py" line="868"/>
        <source>All files (*)</source>
        <translation>Všetky súbory (*.*)</translation>
    </message>
    <message>
        <location filename="window.py" line="952"/>
        <source>Plain text (*.txt)</source>
        <translation>Jednoduchý text (*.txt)</translation>
    </message>
    <message>
        <location filename="window.py" line="1040"/>
        <source>Save file</source>
        <translation>Uložiť súbor</translation>
    </message>
    <message>
        <location filename="window.py" line="982"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Nie je možné uložiť, pretože súbor je len nna čítanie!</translation>
    </message>
    <message>
        <location filename="window.py" line="1030"/>
        <source>Export document to ODT</source>
        <translation>Exportovať dokument do ODT</translation>
    </message>
    <message>
        <location filename="window.py" line="1030"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>OpenDocument textové súbory (*.odt)</translation>
    </message>
    <message>
        <location filename="window.py" line="1040"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>HTML súbory (*.html *.htm)</translation>
    </message>
    <message>
        <location filename="window.py" line="1062"/>
        <source>Export document to PDF</source>
        <translation>Exportovať dokument do PDF</translation>
    </message>
    <message>
        <location filename="window.py" line="1062"/>
        <source>PDF files (*.pdf)</source>
        <translation>PDF súbory (*.pdf)</translation>
    </message>
    <message>
        <location filename="window.py" line="1079"/>
        <source>Print document</source>
        <translation>Tlačiť dokument</translation>
    </message>
    <message>
        <location filename="window.py" line="1100"/>
        <source>Export document</source>
        <translation>Exportovať dokument</translation>
    </message>
    <message>
        <location filename="window.py" line="1119"/>
        <source>Failed to execute the command:</source>
        <translation>Nepodarilo sa spustiť príkaz:</translation>
    </message>
    <message>
        <location filename="window.py" line="1237"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Dokument bol zmenený.
Chcete uložiť vaše zmeny?</translation>
    </message>
    <message>
        <location filename="window.py" line="1261"/>
        <source>HTML code</source>
        <translation>HTML kód</translation>
    </message>
    <message>
        <location filename="window.py" line="1272"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Autor: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="window.py" line="1272"/>
        <source>Website</source>
        <translation>Webová stránka</translation>
    </message>
    <message>
        <location filename="window.py" line="1272"/>
        <source>Markdown syntax</source>
        <translation>Markdown syntax</translation>
    </message>
    <message>
        <location filename="window.py" line="186"/>
        <source>About ReText</source>
        <translation>O ReText</translation>
    </message>
    <message>
        <location filename="window.py" line="955"/>
        <source>%s files</source>
        <comment>Example of final string: Markdown files</comment>
        <translation>Súbory %s</translation>
    </message>
    <message>
        <location filename="window.py" line="1272"/>
        <source>Simple but powerful editor for Markdown and reStructuredText</source>
        <translation>Jednoduchý a pritom efektívny editor pre Markdown a reStructuredText</translation>
    </message>
    <message>
        <location filename="window.py" line="1272"/>
        <source>reStructuredText syntax</source>
        <translation>reStructuredText syntax</translation>
    </message>
    <message>
        <location filename="window.py" line="685"/>
        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="279"/>
        <source>Default markup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="592"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="96"/>
        <source>Set encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="927"/>
        <source>Select file encoding from the list:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1217"/>
        <source>Reload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="107"/>
        <source>Next tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="109"/>
        <source>Previous tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="137"/>
        <source>Table mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="140"/>
        <source>FakeVim mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1200"/>
        <source>This file has been deleted by other application.
Please make sure you save the file before exit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1208"/>
        <source>This document has been modified by other application.
Do you want to reload the file (this will discard all your changes)?
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1213"/>
        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="117"/>
        <source>Change editor font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="119"/>
        <source>Change preview font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1272"/>
        <source>ReText %s (using PyMarkups %s)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
